% Parser.pl contains the parsing predicates.
% Created and modified by Pierre Nugues


parse(FirstReport, FirstSentence, ComplexPG) :- 
	multiword_detector(FirstReport, FirstReport_MW),
	read_sentences(FirstReport_MW, FirstSentence, _),
	simple_parse(FirstSentence, Parse),
	complex_ng(Parse, ComplexNG),
	complex_ng(ComplexNG, ComplexNG2),
	complex_ng(ComplexNG2, ComplexNG3),
	complex_pg(ComplexNG3, ComplexPG1),
	complex_pg(ComplexPG1, ComplexPG).

%read_sentences(FirstReport, FirstSentence, RestSentences) :-
read_sentences(FirstReport, FirstSentence, _) :-
	sentences(Sentences, FirstReport, []),
	!,
	member(FirstSentence, Sentences).

% Complex noun groups are linked with variants of de, pour, et and ou.	
complex_ng([], []).
complex_ng([ng(NG1), pg([DE | NG2]) | Rest1], [ng(NG3) | Rest2]) :-
	(DE == de; DE == des; DE == du; DE == d;
	DE == pour; DE == 'Pour'; 
	DE == et; DE == ou),
	append(NG1, [DE | NG2], NG3),
	!,
%	write(NG3), nl,
	complex_ng(Rest1, Rest2).

% Complex noun groups are linked with inf groups.	
complex_ng([ng(NG1), infg([DE | NG2]) | Rest1], [ng(NG3) | Rest2]) :-
	(DE == de; DE == des; DE == du; DE == d),
	append(NG1, [DE | NG2], NG3),
	!,
%	write(NG3), nl,
	complex_ng(Rest1, Rest2).

%Appositive noun groups, excluding pronouns
complex_ng([ng(NG1), ng(NG2) | Rest1], [ng(NG3) | Rest2]) :-
	NG1 = [PRO1 | _],
	NG2 = [PRO2 | _],
	\+ pronoun(PRO1, _, _),
	\+ pronoun(PRO2, _, _), 
	\+ pronoun_rel(PRO1, _, _),
	\+ pronoun_rel(PRO2, _, _), 
	append(NG1, NG2, NG3),
	!,
%	write(NG3), nl,
	complex_ng(Rest1, Rest2).

complex_ng([X | Rest1], [X | Rest2]) :-
	!,
	complex_ng(Rest1, Rest2).

complex_pg([], []).
complex_pg([pg(NG1), pg([DE | NG2]) | Rest1], [pg(NG3) | Rest2]) :-
	(DE == de; DE == des; DE == du; DE == d),
	append(NG1, [DE | NG2], NG3),
	!,
%	write(NG3), nl,
	complex_pg(Rest1, Rest2).
complex_pg([X | Rest1], [X | Rest2]) :-
	!,
	complex_pg(Rest1, Rest2).


simple_parse(Lin, Lout) :-
%	multiword_detector(Lin, Lout1),
	group_detector(Lin, Lout),
	!.
	
multiword_detector(In, Out) :-
	word_stream_1(Beginning, MultiWord, End, In, []),
	append(Beginning, [MultiWord], Head),
	append(Head, Rest, Out),
	multiword_detector(End, Rest),
	!.
multiword_detector(End, End) :- !.

word_stream_1(Beginning, MultiWord, End) -->
	beginning(Beginning),
	multiword(MultiWord),
	end(End).


group_detector(In, Out) :-
	word_stream_2(Beginning, Group, End, In, []),
	group_detector(End, Rest),
	append(Beginning, [Group], Head),
	append(Head, Rest, Out). %, write(Beginning), write(' ' ).
group_detector(End, End).

word_stream_2(Beginning, Group, End) -->
	beginning(Beginning),
	group(Group),
	end(End).



group(infg(Group)) --> inf_group(Group). % {write(Group), nl}.
group(pg(Group)) --> prep_group(Group).
group(vg(Group)) --> infinitive_group(Group). %{write(Group), nl}. % No difference with verb group
group(gg(Group)) --> gerund_group(Group). %, {write(Group), nl}.
group(vg(Group)) --> verb_group(Group).
group(ng(Group)) --> noun_group(Group).
group(rg(Group)) --> adv_group(Group).
group(rp([Group])) --> pronoun_rel(Group).
group(cs([Group])) --> conj_sub(Group).


inf_group([P1, P2 | NG]) --> prep(P1), prep(P2), infinitive_group(NG). %, {write([P1, P2 | NG]), nl}.
inf_group([P | NG]) --> prep(P), infinitive_group(NG). %, {write([P | NG]), nl}.


prep_group([P1, P2 | NG]) --> prep(P1), prep(P2), noun_group(NG). % Sometime prep coumpound ie "par contre" -- Changement
prep_group([P | NG]) --> prep(P), noun_group(NG).

gerund_group([en, CL | VG]) --> [en], clitic(CL), gerund_group(VG).
gerund_group(['En', CL | VG]) --> ['En'], clitic(CL), gerund_group(VG).
gerund_group([en | VG]) --> [en], gerund_group(VG).
gerund_group(['En' | VG]) --> ['En'], gerund_group(VG).
gerund_group(VG) --> gerund_chain(VC), [t], adjective(ADJ), [que],
	{append(VC, [t, ADJ, que], VG)}. %, {write(VG), nl}.
gerund_group(VG) --> gerund_chain(VC), [t], past_participle(PP), [que],
	{append(VC, [t, PP, que], VG)}.
gerund_group(VG) --> gerund_chain(VC), past_participle(PP), [que],
	{append(VC, [PP, que], VG)}.
gerund_group(VG) --> gerund_chain(VC), [t], adjective(ADJ),
	{append(VC, [t, ADJ], VG)}. %, {write(VG), nl}.
gerund_group(VG) --> gerund_chain(VC), [t], past_participle(PP),
	{append(VC, [t, PP], VG)}.
gerund_group(VG) --> gerund_chain(VC), past_participle(PP), {append(VC, [PP], VG)}.
gerund_group([RBN1, CL, V, RBN2]) --> adv_neg(RBN1), clitic(CL), gerund(V), adv_neg(RBN2).
gerund_group([RBN1, V, RBN2]) --> adv_neg(RBN1), gerund(V), adv_neg(RBN2).
gerund_group([CL, V, ADJ]) --> clitic(CL), aux_conj_gerund_be(V), adj(ADJ). %, {write([CL, V, ADJ]), nl}.
gerund_group([CL, V]) --> clitic(CL), gerund(V).
gerund_group([V, ADJ]) --> aux_conj_gerund_be(V), adj(ADJ). %, {write([V, ADJ]), nl}.
gerund_group([V, I]) --> gerund(V),  infinitive(I).
gerund_group(GC) --> gerund_chain(GC).
gerund_group([V]) --> gerund(V).


gerund_chain([RBN, CL, AC, RB1, RB2]) --> adv_neg(RBN), clitic(CL), aux_conj_gerund(AC), adv(RB1), adv(RB2).
gerund_chain([RBN, AC, RB1, RB2]) --> adv_neg(RBN), aux_conj_gerund(AC), adv(RB1), adv(RB2).
gerund_chain([RBN, CL, AC, RB]) --> adv_neg(RBN), clitic(CL), aux_conj_gerund(AC), adv(RB).
gerund_chain([RBN, AC, RB]) --> adv_neg(RBN), aux_conj_gerund(AC), adv(RB).
gerund_chain([RBN, AC]) --> adv_neg(RBN), aux_conj_gerund(AC).		%ne ... que
gerund_chain([CL, AC, RB]) --> clitic(CL), aux_conj_gerund(AC), adv(RB).
gerund_chain([AC, RB]) --> aux_conj_gerund(AC), adv(RB).
gerund_chain([CL, AC]) --> clitic(CL), aux_conj_gerund(AC).
gerund_chain([AC]) --> aux_conj_gerund(AC).


infinitive_group(VG) --> infinitive_chain_2(VC), [t], past_participle(PP), [que],
	{append(VC, [t, PP, que], VG)}.
infinitive_group(VG) --> infinitive_chain_2(VC), past_participle(PP), [que],
	{append(VC, [PP, que], VG)}.
infinitive_group(VG) --> infinitive_chain_2(VC), [t], past_participle(PP),
	{append(VC, [t, PP], VG)}.
infinitive_group(VG) --> infinitive_chain_2(VC), past_participle(PP),
	{append(VC, [PP], VG)}.

infinitive_group(IG) --> infinitive_chain(IC), clitic(C), infinitive(I), past_participle(PP), {append(IC, [C, I, PP], IG)}.
infinitive_group(IG) --> infinitive_chain(IC), clitic(C), infinitive(I),
	{append(IC, [C, I], IG)}.
infinitive_group(IG) --> infinitive_chain(IC), aux_infinitive(I), past_participle(PP),
	{append(IC, [I, PP], IG)}.
infinitive_group(IG) --> infinitive_chain(IC), infinitive(I1), infinitive(I2),
	{append(IC, [I1, I2], IG)}.
infinitive_group(IG) --> infinitive_chain(IC), infinitive(I),
	{append(IC, [I], IG)}.
infinitive_group([CL, I1, I2]) --> clitic(CL), infinitive(I1), infinitive(I2).
infinitive_group([CL, I]) --> clitic(CL), infinitive(I).
infinitive_group([CL, I]) --> clitic(CL), aux_infinitive(I).
infinitive_group([I1, I2]) --> infinitive(I1), infinitive(I2).
infinitive_group([I]) --> infinitive(I).
infinitive_group([I]) --> aux_infinitive(I).

%infinitive_chain(VG) --> gerund_group(VG).
infinitive_chain(VG) --> verb_group(VG).
infinitive_chain([I]) --> infinitive(I).
infinitive_chain([en, train, de]) --> [en, train, de].
infinitive_chain([ne, pas]) --> [ne, pas].


%infinitive_chain([P, I]) --> prep(P), infinitive(I).
%infinitive_chain([P]) --> prep(P).


infinitive_chain_2([RBN, CL, AC, RB1, RB2]) -->
	adv_neg(RBN), clitic(CL), aux_infinitive(AC), adv(RB1), adv(RB2).
infinitive_chain_2([RBN, AC, RB1, RB2]) -->
	adv_neg(RBN), aux_infinitive(AC), adv(RB1), adv(RB2).
infinitive_chain_2([RBN, CL, AC, RB]) -->
	adv_neg(RBN), clitic(CL), aux_infinitive(AC), adv(RB).
infinitive_chain_2([RBN, AC, RB]) --> adv_neg(RBN), aux_infinitive(AC), adv(RB).
infinitive_chain_2([RBN, AC]) --> adv_neg(RBN), aux_infinitive(AC).		%ne ... que
infinitive_chain_2([CL, AC, RB]) --> clitic(CL), aux_infinitive(AC), adv(RB).
infinitive_chain_2([AC, RB]) --> aux_infinitive(AC), adv(RB).
infinitive_chain_2([CL, AC]) --> clitic(CL), aux_infinitive(AC).
infinitive_chain_2([AC]) --> aux_infinitive(AC).

verb_chain_be([RBN, CL, AC, RB1, RB2]) --> adv_neg(RBN), clitic(CL), aux_conj_be(AC), adv(RB1), adv(RB2).
verb_chain_be([RBN, AC, RB1, RB2]) --> adv_neg(RBN), aux_conj_be(AC), adv(RB1), adv(RB2).
verb_chain_be([RBN, CL, AC, RB]) --> adv_neg(RBN), clitic(CL), aux_conj_be(AC), adv(RB).
verb_chain_be([RBN, AC, RB]) --> adv_neg(RBN), aux_conj_be(AC), adv(RB).
verb_chain_be([RBN, AC]) --> adv_neg(RBN), aux_conj_be(AC).		%ne ... que
verb_chain_be([CL, AC, RB]) --> clitic(CL), aux_conj_be(AC), adv(RB).
verb_chain_be([AC, RB]) --> aux_conj_be(AC), adv(RB).
verb_chain_be([CL, AC]) --> clitic(CL), aux_conj_be(AC).
verb_chain_be([AC]) --> aux_conj_be(AC).


verb_chain([RBN, CL, AC, RB1, RB2]) --> adv_neg(RBN), clitic(CL), aux_conj(AC), adv(RB1), adv(RB2).
verb_chain([RBN, AC, RB1, RB2]) --> adv_neg(RBN), aux_conj(AC), adv(RB1), adv(RB2).
verb_chain([RBN, CL, AC, RB]) --> adv_neg(RBN), clitic(CL), aux_conj(AC), adv(RB).
verb_chain([RBN, AC, RB]) --> adv_neg(RBN), aux_conj(AC), adv(RB).
verb_chain([RBN, AC]) --> adv_neg(RBN), aux_conj(AC).		%ne ... que
verb_chain([CL, AC, RB]) --> clitic(CL), aux_conj(AC), adv(RB).
verb_chain([AC, RB]) --> aux_conj(AC), adv(RB).
verb_chain([CL, AC]) --> clitic(CL), aux_conj(AC).
verb_chain([AC]) --> aux_conj(AC).


verb_group(VG) --> verb_chain(VC), [t], pp_group(PP), [que],
	{append(VC, [t | PP], VG1), append(VG1, [que], VG)}.
verb_group(VG) --> verb_chain(VC), pp_group(PP), [que],
	{append(VC, PP, VG1), append(VG1, [que], VG)}.
verb_group(VG) --> verb_chain(VC), [t], adj_group(ADJ),
	{append(VC, [t | ADJ], VG)}. %, {write(VG), nl}.
verb_group(VG) --> verb_chain(VC), [t], pp_group(PP),
	{append(VC, [t | PP], VG)}.
verb_group(VG) --> verb_chain(VC), [t], {append(VC, [t], VG)}.
verb_group(VG) --> verb_chain_be(VC), adj_group(ADJ),
	{append(VC, ADJ, VG)}. %, {write(VG), nl}.
verb_group(VG) --> verb_chain(VC), pp_group(PP), {append(VC, PP, VG)}.
verb_group([RBN1, CL, V, RBN2]) -->
	adv_neg(RBN1), clitic(CL), tensed_verb(V), adv_neg(RBN2).
verb_group([RBN1, V, RBN2]) -->
	adv_neg(RBN1), tensed_verb(V), adv_neg(RBN2).
verb_group([RBN, V]) -->
	adv_neg(RBN), tensed_verb(V).
verb_group([CL, V]) --> clitic(CL), tensed_verb(V).
verb_group([V]) --> tensed_verb(V).


% adj_group(-AdjGroup)
% detects a list of words making an adjective
% group and unifies AdjGroup with it

/*
adj_group([RB, A | AG]) -->
	adv(RB), adj(A), adj_group(AG).
adj_group([A | AG]) -->
	adj(A), adj_group(AG).
adj_group([A]) --> adj(A).
*/
adj_group([RB | AG]) -->
	adv(RB), adj_group(AG).
adj_group([A | AG]) -->
	adj(A), adj_group(AG).
adj_group([A]) --> adj(A).

% pp_group(-PPGroup)
% detects a list of words making a past particple
% group and unifies PPGroup with it

pp_group([RB | PP]) -->
	adv(RB), pp_group(PP).
pp_group([PP]) --> past_participle(PP).

% adv_group(-ADVGroup)
% detects a list of words making an adverb
% group and unifies PPGroup with it

adv_group([RB | ADVG]) -->
	adv(RB), adv_group(ADVG).
adv_group([ADV]) --> adv(ADV).


% noun_group(-NounGroup)
% detects a list of words making a noun group and 
% unifies NounGroup with it
noun_group(NG) -->
	det(D), noun_group_no_det(N), ['-', l],
	{append([D], N, NG1), append(NG1, [l], NG)}.
noun_group(NG) -->
	det(D), noun_group_no_det(N), [l],
	{append([D], N, NG1), append(NG1, [l], NG)}.
noun_group(NG) -->
	det(D), noun_group_no_det(N),
	{append([D], N, NG)}.
noun_group(NG) --> noun_group_no_det(NG).
%noun_group([D, PN]) --> det(D), proper_noun(PN). %{write(D), write(PN), nl}.
%noun_group([PN]) --> proper_noun(PN).
noun_group([PRO]) --> pronoun(PRO).
%noun_group([PRO, clitic]) --> clitic(PRO).

noun_group_no_det(NG) --> 
	adj_group(AG1), noun(N), adj_group(AG2), 
	{append(AG1, [N], NG1), append(NG1, AG2, NG)}.
noun_group_no_det(NG) --> 
	adj_group(AG), noun(N),
	{append(AG, [N], NG)}.
%noun_group_no_det([X, N | [PN]]) --> 
%	[Number], voie(N), proper_noun(PN), {number(Number)}.
noun_group_no_det([_, N | [PN]]) --> 
	[Number], voie(N), proper_noun(PN), {number(Number)}.
noun_group_no_det([N | [PN]]) --> 
	voie(N), proper_noun(PN).
noun_group_no_det(NG) --> 
	noun(N), adj_group(AG), 
	{append([N], AG, NG)}.
noun_group_no_det(NG) --> speed(NG).
%noun_group_no_det(NG) --> distance(NG).
noun_group_no_det([N]) --> noun(N).
noun_group_no_det([PN]) --> proper_noun(PN).
noun_group_no_det(AG) --> adj_group(AG).

beginning(X, Y, Z) :- append(X, Z, Y).
end(X, Y, Z) :- append(X, Z, Y).

det(beaucoup_de) --> [beaucoup_de].
det('Ce') --> ['Ce'].
det(ce) --> [ce].
det(cet) --> [cet].
det('Cet') --> ['Cet'].
det(cette) --> [cette].
det(l) --> [l], [''''].
det('L') --> ['L'], [''''].
det(le) --> [le].
det('Le') --> ['Le'].
det(les) --> [les].
det('Les') --> ['Les'].
det(la) --> [la].
det('La') --> ['La'].
det(ma) --> [ma].
det('Ma') --> ['Ma'].
det(mon) --> [mon].
det('Mon') --> ['Mon'].
det(mes) --> [mes].
det(nos) --> [nos].
det(notre) --> [notre].
det(l_une_des) --> [l_une_des].
det('Pas_de') --> ['Pas_de'].
%det(pas_de) --> [pas_de].
det(sa) --> [sa].
det('Sa') --> ['Sa'].
det(ses) --> [ses].
det(son) --> [son].
det(toute_la) --> [toute_la].
det(tout_le) --> [tout_le].
det(un) --> [un].
det('Un') --> ['Un'].
det(une) --> [une].

nombre(deux) --> [deux].
nombre(X) --> [X], {number(X)}.

adj('Fort') --> ['Fort'].
adj(amiable) --> [amiable].
adj(amovible) --> [amovible].
adj(arrire) --> [arrire].
adj(aucun) --> [aucun].
adj(aucune) --> [aucune].
adj(autre) --> [autre].
adj(autres) --> [autres].
adj(avant) --> [avant].
adj(bas) --> [bas].
adj(bis) --> [bis].
adj(blanche) --> [blanche].
adj(blanches) --> [blanches].
adj(blancs) --> [blancs].
adj(borde) --> [borde].
adj(brutal) --> [brutal].
adj(centrale) --> [centrale].
adj(certain) --> [certain].
adj(chaque) --> [chaque].
adj(confiante) --> [confiante].
adj(conscient) --> [conscient].
adj(continue) --> [continue].
adj(dense) --> [dense].
adj(dernier) --> [dernier].
adj(dernires) --> [dernires].
adj(deux) --> [deux].
adj(deuxime) --> [deuxime].
adj(diffrentes) --> [diffrentes].
adj(double) --> [double].
adj(droit) --> [droit].
adj(droite) --> [droite].
adj(extrieure) --> [extrieure].
adj(faible) --> [faible].
adj(fort) --> [fort].
adj(forte) --> [forte].
adj(frontal) --> [frontal].
adj(gauche) --> [gauche].
adj(giratoire) --> [giratoire].
adj(glissante) --> [glissante].
adj(grande) --> [grande].
adj(horizontale) --> [horizontale].
adj(impossible) --> [impossible].
adj(indonsien) --> [indonsien].
adj(intense) --> [intense].
adj(inverse) --> [inverse].
adj(invisible) --> [invisible].
adj(involontaire) --> [involontaire].
adj(invitable) --> [invitable].
%adj(juste) --> [juste].
adj(latral) --> [latral].
adj(libre) --> [libre].
adj(lger) --> [lger].
adj(manuelle) --> [manuelle].
adj(mort) --> [mort].
adj(mdiane) --> [mdiane].
adj(mtallique) --> [mtallique].
adj(mme) --> [mme].
adj(normale) --> [normale].
adj(obligatoire) --> [obligatoire].
adj(orange) --> [orange].
adj(petite) --> [petite].
adj(plein) --> [plein].
adj(plusieurs) --> [plusieurs].
adj(possible) --> [possible].
adj(prcdent) --> [prcdent].
adj(premier) --> [premier].
adj(premire) --> [premire].
adj(principale) --> [principale].
adj(prioritaire) --> [prioritaire].
adj(proche) --> [proche].
adj(provisoire) --> [provisoire].
adj(prcise) --> [prcise].
adj(quelques) --> [quelques].
adj(rigoureux) --> [rigoureux].
adj(rouge) --> [rouge].
adj(second) --> [second].
adj(seul) --> [seul]. %%changement
adj(sinueuse) --> [sinueuse].
adj(tricolore) --> [tricolore].
adj(tel) --> [tel].
adj(telle) --> [telle].
adj(unique) --> [unique].
adj(vert) --> [vert].
adj(visuels) --> [visuels].
adj(vive) --> [vive].
adj(pres) --> [pres].
adj(troite) --> [troite].
adj('1er') --> ['1er'].
adj('1re') --> ['1re'].
adj('3ime') --> ['3ime'].
adj('3me') --> ['3me'].


adj(no_immatriculation) --> [no_immatriculation].

adj(X) --> nombre(X).
%adj() --> [].

adj(A) --> past_participle(A).
%adj(A) --> gerund(A).

adv('Bien_entendu') --> ['Bien_entendu'].
adv('Malheureusement') --> ['Malheureusement'].
adv(_gauche) --> [_gauche].
adv(_droite) --> [_droite].
adv(ailleurs) --> [ailleurs].
adv(alors) --> [alors].
adv(aussi) --> [aussi].
adv(au_loin) --> [au_loin].
adv(beaucoup) --> [beaucoup].
adv(bien) --> [bien].
adv(brusquement) --> [brusquement].
adv(certainement) --> [certainement].
adv(compltement) --> [compltement].
adv(correctement) --> [correctement].
adv(donc) --> [donc].
adv(doucement) --> [doucement].
adv(du_tout) --> [du_tout].
adv(encore) --> [encore].
adv(en_face) --> [en_face].
adv(fortement) --> [fortement].
adv(gravement) --> [gravement].
adv(immdiatement) --> [immdiatement].
adv(initialement) --> [initialement].
adv(involontairement) --> [involontairement].
adv(juste) --> [juste].
adv(lentement) --> [lentement].
adv(loin) --> [loin].
adv(lgrement) --> [lgrement].
adv(maintenant) --> [maintenant].
adv(mal) --> [mal].
adv(momentanment) --> [momentanment].
adv(normalement) --> [normalement].
adv(notamment) --> [notamment].
adv(par_consquent) --> [par_consquent].
adv(peu) --> [peu].
adv(perpendiculairement) --> [perpendiculairement].
adv(plus) --> [plus].
adv(plus_de) --> [plus_de].
adv(prs) --> [prs].
adv(quasiment) --> [quasiment].
adv(rien) --> [rien].
adv(sans_doute) --> [sans_doute].
adv(tard) --> [tard].
adv(totalement) --> [totalement].
adv(toujours) --> [toujours].
adv(tout_droit) --> [tout_droit].
adv(tout__fait) --> [tout__fait].
adv(trop) --> [trop].
adv(trs) --> [trs].
adv(violemment) --> [violemment].
adv(visiblement) --> [visiblement].
adv(vite) --> [vite].
adv(_peine) --> [_peine].
adv(galement) --> [galement].
adv(X) --> adv_neg(X).

adv_neg('Ne') --> ['Ne'].
adv_neg(ne) --> [ne].
adv_neg(n) --> [n], [''''].
adv_neg(pas) --> [pas].
%adv_neg(que) --> [que].	% ne ... que

voie('Avenue') --> ['Avenue'].
voie('Av') --> ['Av'].
voie(ave) --> [ave].
voie('Bd') --> ['Bd'].
voie('Boulevard') --> ['Boulevard'].
voie('Nationale') --> ['Nationale'].
voie('Parc') --> ['Parc'].
voie('Pont') --> ['Pont'].
voie('Voie') --> ['Voie'].
voie(route) --> [route].
voie(ave) --> [ave].
voie(avenue) --> [avenue].
voie(bd) --> [bd].
voie(boulevard) --> [boulevard].
voie(nationale) --> [nationale].
voie(place) --> [place].
voie(priphrique) --> [priphrique].
voie(quai) --> [quai].
voie(rue) --> [rue].
voie(rues) --> [rues].
voie(lyce) --> [lyce].
voie(sortie) --> [sortie].

noun('A_et_B') --> ['A_et_B'].
noun('B') --> ['B'].
noun('D') --> ['D'].
noun('Charretiers') --> ['Charretiers'].
noun('Clio') --> ['Clio'].
noun('Erreur') --> ['Erreur'].
noun('Libration') --> ['Libration'].
noun('Lilas') --> ['Lilas'].
noun('Mdecin') --> ['Mdecin'].
noun('Vhicule') --> ['Vhicule'].
noun(abord) --> [abord].
noun(absence) --> [absence].
noun(abme) --> [abme].
noun(accident) --> [accident].
noun(adversaire) --> [adversaire].
noun(aile) --> [aile].
noun(allure) --> [allure].
noun(angle) --> [angle].
noun(approche) --> [approche].
noun(arbre) --> [arbre].
noun(arbres) --> [arbres].
noun(arrt) --> [arrt].
noun(assurances) --> [assurances].
noun(automobiliste) --> [automobiliste].
noun(autoroute) --> [autoroute].
noun(autoroute_A1) --> [autoroute_A1].
noun(averse) --> [averse].
noun(bande) --> [bande].
noun(bandes) --> [bandes].
noun(barrire) --> [barrire].
noun(benne) --> [benne].
noun(berges) --> [berges].
noun(bicyclette) --> [bicyclette].
noun(bord) --> [bord].
noun(bouchon) --> [bouchon].
noun(boule) --> [boule].
noun(braquage) --> [braquage].
noun(brouillard) --> [brouillard].
noun(bton) --> [bton].
noun(camion) --> [camion].
noun(camionnette) --> [camionnette].
noun(capot) --> [capot].
noun(carambolage) --> [carambolage].
noun(carrefour) --> [carrefour].
noun(cas) --> [cas].
noun(cause) --> [cause].
noun(centre) --> [centre].
noun(certitude) --> [certitude].
noun(changement) --> [changement].
noun(chauffeur) --> [chauffeur].
noun(chausse) --> [chausse].
noun(chemin) --> [chemin].
noun(chien) --> [chien].
noun(choc) --> [choc].
noun(chocs) --> [chocs].
noun(chute) --> [chute].
noun(ciment) --> [ciment].
noun(circulation) --> [circulation].
noun(clignotant) --> [clignotant].
noun(clture) --> [clture].
noun(collision) --> [collision].
noun(collge) --> [collge].
noun(colonne) --> [colonne].
noun(commune) --> [commune].
noun(compte) --> [compte].
noun(concentration) --> [concentration].
noun(conducteur) --> [conducteur].
noun(conducteurs) --> [conducteurs].
noun(conductrice) --> [conductrice].
noun(conduite) --> [conduite].
noun(constat) --> [constat].
noun(contrle) --> [contrle].
noun(coordonnes) --> [coordonnes].
noun(coquelicots) --> [coquelicots].
noun(cot) --> [cot].
noun(coup) --> [coup].
noun(course) --> [course].
noun(courses) --> [courses].
noun(croisement) --> [croisement].
noun(croix) --> [croix].
noun(croquis) --> [croquis].
noun(cycliste) --> [cycliste].
noun(ct) --> [ct].
noun(demande) --> [demande].
noun(demarrage) --> [demarrage].
noun(devant) --> [devant].
noun(direction) --> [direction].
noun(dires) --> [dires].
noun(distance) --> [distance].
noun(domicile) --> [domicile].
noun(dommages) --> [dommages].
noun(dos) --> [dos].
noun(douleur) --> [douleur].
noun(douleurs) --> [douleurs].
noun(doute) --> [doute].
noun(dclaration) --> [dclaration].
noun(dgt) --> [dgt].
noun(dgts) --> [dgts].
noun(dpannage) --> [dpannage].
noun(dpanneur) --> [dpanneur].
noun(effet) --> [effet].
noun(embouteillage) --> [embouteillage].
noun(emplacement) --> [emplacement].
noun(endroit) --> [endroit].
noun(endroits) --> [endroits].
noun(engin) --> [engin].
noun(enlvement) --> [enlvement].
noun(entre) --> [entre].
noun(envoi) --> [envoi].
noun(essence) --> [essence].
noun(face) --> [face].
noun(fait) --> [fait].
noun(faon) --> [faon].
noun(fermeture) --> [fermeture].
noun(feu) --> [feu].
noun(feux) --> [feux].
noun(file) --> [file].
noun(files) --> [files].
noun(flaque) --> [flaque].
noun(fleurs) --> [fleurs].
noun(flot) --> [flot].
noun(flux) --> [flux].
noun(flches) --> [flches].
noun(fonctionnement) --> [fonctionnement].
noun(fond) --> [fond].
noun(foss) --> [foss].
noun(fouet) --> [fouet].
noun(franchissement) --> [franchissement].
noun(frein) --> [frein].
noun(freins) --> [freins].
noun(fuite) --> [fuite].
noun(fvrier) --> [fvrier].
noun(garage) --> [garage].
noun(garagiste) --> [garagiste].
noun(garde) --> [garde].
noun(gendarmerie) --> [gendarmerie].
noun(gendarmes) --> [gendarmes].
noun(golf) --> [golf].
noun(graviers) --> [graviers].
noun(haie) --> [haie].
noun(hauteur) --> [hauteur].
noun(heure) --> [heure].
noun(huile) --> [huile].
noun(hsitation) --> [hsitation].
noun(immeuble) --> [immeuble].
noun(immobilisation) --> [immobilisation].
noun(impact) --> [impact].
noun(importance) --> [importance].
noun(impossibilit) --> [impossibilit].
noun(infraction) --> [infraction].
noun(inspection) --> [inspection].
noun(intersection) --> [intersection].
noun(jour) --> [jour].
noun(lapin) --> [lapin].
noun(lieu) --> [lieu].
noun(lieux) --> [lieux].
noun(ligne) --> [ligne].
noun(limitation) --> [limitation].
noun(longueur) --> [longueur].
noun(lundi) --> [lundi].
noun(main) --> [main].
noun(maison) --> [maison].
noun(malade) --> [malade].
noun(manire) --> [manire].
noun(manoeuvre) --> [manoeuvre].
noun(marche) --> [marche].
noun(marquage) --> [marquage].
noun(mare) --> [mare].
noun(matin) --> [matin].
noun(maximum) --> [maximum].
noun(milieu) --> [milieu].
noun(moment) --> [moment].
noun(motard) --> [motard].
noun(moto) --> [moto].
noun(motocyclette) --> [motocyclette].
noun(motocycliste) --> [motocycliste].
noun(mur) --> [mur].
noun(mtres) --> [mtres].
noun(niveau) --> [niveau].
noun(noms) --> [noms].
noun(nuit) --> [nuit].
noun(nuque) --> [nuque].
noun(observation) --> [observation].
noun(ordinaire) --> [ordinaire].
noun(panne) --> [panne].
noun(panneau) --> [panneau].
noun(panneaux) --> [panneaux].
noun(pare_chocs) --> [pare_choc].
noun(pare_chocs) --> [pare_chocs].
noun(parking) --> [parking].
noun(part) --> [part].
noun(partie) --> [partie].
noun(passage) --> [passage].
noun(peine) --> [peine].
noun(pente) --> [pente].
noun(personne) --> [personne].
noun(phare) --> [phare].
noun(phares) --> [phares].
noun(photos) --> [photos].
noun(pied) --> [pied].
noun(pilier) --> [pilier].
noun(piton) --> [piton].
noun(plancher) --> [plancher].
noun(pneu) --> [pneu].
noun(poignet) --> [poignet].
noun(point) --> [point].
noun(police) --> [police].
noun(pompe) --> [pompe].
noun(pompiers) --> [pompiers].
noun(pont) --> [pont].
noun(porte) --> [porte].
noun(portion) --> [portion].
noun(portire) --> [portire].
noun(possibilit) --> [possibilit].
noun(pression) --> [pression].
noun(priorit) --> [priorit].
noun(protection) --> [protection].
noun(proximit) --> [proximit].
noun(prsence) --> [prsence].
noun(pdale) --> [pdale].
noun(rail) --> [rail].
noun(raison) --> [raison].
noun(ralentissement) --> [ralentissement].
noun(rambarde) --> [rambarde].
noun(rapport) --> [rapport].
noun(recto) --> [recto].
noun(remorque) --> [remorque].
noun(respect) --> [respect].
noun(responsable) --> [responsable].
noun(retard) --> [retard].
noun(rond_point) --> [rond_point].
noun(roue) --> [roue].
noun(rserve) --> [rserve].
noun(rsidence) --> [rsidence].
noun(rtroviseur) --> [rtroviseur].
noun(station_service) --> [station_service].
noun(schma) --> [schma].
noun(secondes) --> [secondes].
noun(camion) --> [semi_remorque]. % modification ajout => je prefere diminuer le nombre de mots du dictionnaire
% noun(semi_remorque) --> [semi_remorque].
noun(sens) --> [sens].
noun('Ford') --> [sierra].%(ajout) 
noun(signal) --> [signal].
noun(signalisation) --> [signalisation].
noun(sige) --> [sige].
noun(sous_sol) --> [sous_sol].
noun(sol) --> [sol].
noun(stationnement) --> [stationnement].
noun(stop) --> [stop].
noun(suite) --> [suite].
noun(scurit) --> [scurit].
noun(srie) --> [srie].
noun(table) --> [table].
noun(temps) --> [temps].
noun(tiers) --> [tiers].
noun(tonneaux) --> [tonneaux].
noun(torts) --> [torts].
noun(tour) --> [tour].
noun(tournant) --> [tournant].
noun(traces) --> [traces].
noun(trafic) --> [trafic].
noun(trajectoire) --> [trajectoire].
noun(travail) --> [travail].
noun(travaux) --> [travaux].
noun(traverse) --> [traverse].
noun(trottoir) --> [trottoir].
noun(type) --> [type].
noun(tmoin) --> [tmoin].
noun(tte) --> [tte].
noun(urgence) --> [urgence].
noun(usager) --> [usager].
noun(vacances) --> [vacances].
noun(verglas) --> [verglas].
noun(vigueur) --> [vigueur].
noun(ville) --> [ville].
noun(virage) --> [virage].
noun(visibilit) --> [visibilit].
noun(visite) --> [visite].
noun(vitesse) --> [vitesse].
noun(voie) --> [voie].
noun(voies) --> [voies].
noun(voiture) --> [voiture].
noun(voitures) --> [voitures].
noun(voix) --> [voix].
noun(volant) --> [volant].
noun(vue) --> [vue].
noun(vhicule) --> [vhicule].
noun(vhicules_A_et_B) --> [vhicules_A_et_B].
noun(vhicule_a) --> [vhicule_a].
noun(vhicule_b) --> [vhicule_b].
noun(vhicule_c) --> [vhicule_c].
noun(vhicules) --> [vhicules].
noun(cart) --> [cart].
noun(glise) --> [glise].
noun(tendue) --> [tendue].
noun(time_value) --> [time_value].
noun(date_value) --> [date_value].
noun(distance_value) --> [distance_value].

noun(X) --> voie(X).

%noun() --> [].

pronoun(ceci) --> [ceci].
pronoun(celui_ci) --> [celui_ci].
pronoun('Celui_ci') --> ['Celui_ci'].  
pronoun(celle_ci) --> [celle_ci].
pronoun(celle) --> [celle].
pronoun('C') --> ['C'], [''''].
pronoun(c) --> [c], [''''].
pronoun(ce_qu) --> [ce_qu].
pronoun(ce_qui) --> [ce_qui].
pronoun(je) --> [je].
pronoun(j) --> [j], [''''].
pronoun('je') --> ['Je'].
pronoun('j') --> ['J'], [''''].
pronoun(elle) --> [elle].
pronoun('elle') --> ['Elle'].
pronoun(il) --> [il].
pronoun('il') --> ['Il'].
pronoun(ils) --> [ils].
pronoun(la_mienne) --> [la_mienne].
pronoun(laquelle) --> [laquelle].
pronoun(lequel) --> [lequel].
pronoun(lesquelles) --> [lesquelles].
pronoun(le_sien) --> [le_sien].
pronoun(lui) --> [lui].
pronoun(nous) --> [nous].
pronoun('nous') --> ['Nous'].
pronoun(vous) --> [vous].
pronoun(moi) --> [moi].
pronoun(rien) --> [rien].
pronoun('Rien') --> ['Rien'].

%pronoun(X) --> clitic(X).

clitic(le) --> [le].
clitic(lui) --> [lui].
clitic(l) --> [l], [''''].
%clitic(l) --> [l], ['].
clitic(en) --> [en].
clitic(me) --> [me].
clitic(m) --> [m], [''''].
clitic('Me') --> ['Me'].
clitic(nous) --> [nous]. %changement
clitic(se) --> [se].
clitic(s) --> [s], [''''].
clitic(y) --> [y].

pronoun_rel(qui) --> [qui].
pronoun_rel(o) --> [o].

conj_sub('Alors_que') --> ['Alors_que'].
conj_sub(que) --> [que].
conj_sub(mais) --> [mais].
conj_sub('Lorsque') --> ['Lorsque'].
conj_sub(lorsque) --> [lorsque].
conj_sub(quand) --> [quand].
conj_sub(s) --> [s], [''''].
conj_sub(si) --> [si].
conj_sub(si_bien_que) --> [si_bien_que].
conj_sub(_ce_qu) --> [_ce_qu].


prep('A') --> ['A'].
prep('Aprs') --> ['Aprs'].
prep('Au') --> ['Au'].
prep('Dans') --> ['Dans'].
prep('Sous') --> ['Sous'].
prep(sur) --> ['Sur'].
%prep('Sur') --> ['Sur'].
prep('Aprs') --> ['Aprs'].
prep(aprs) --> [aprs].
prep(au) --> [au].
prep(au_moment_de) --> [au_moment_de].
prep(au_moment_du) --> [au_moment_du].
prep(auprs) --> [auprs].
prep(aux) --> [aux].
prep(avec) --> [avec].
prep(avant) --> [avant].
prep(chez) --> [chez].
prep(contre) --> [contre].
prep(d) --> [d], [''''].
prep('D') --> ['D'], [''''].
prep('D_aprs') --> ['D_aprs'].
prep(dans) --> [dans].
prep('De') --> ['De'].
prep(de) --> [de].
prep(dedans) --> [dedans].
prep(depuis) --> [depuis].
prep('Devant') --> ['Devant'].
prep(derrire) --> [derrire].
prep(des) --> [des].
prep(dessus) --> [dessus].
prep(devant) --> [devant].
prep(du) --> [du].
prep(en) --> [en].
prep('En') --> ['En'].
prep(entre) --> [entre].
prep(face_au) --> [face_au].
prep(hors) --> [hors].
prep(hors_de) --> [hors_de].
prep(juste_aprs) --> [juste_aprs].
prep(juste_avant) --> [juste_avant].
prep('Lors_d') --> ['Lors_d'].
prep(lors_du) --> [lors_du].
prep(par) --> [par].
prep('Par') --> ['Par']. %changement
prep(pour) --> [pour].
prep('Pour') --> ['Pour'].
prep(prs_de) --> [prs_de].
prep(sans) --> [sans].
prep(sous) --> [sous].
prep(sur) --> [sur].
prep(vers) --> [vers].
prep() --> [].

proper_noun('Alfred') --> ['Alfred'].
proper_noun('Argenteuil') --> ['Argenteuil'].
proper_noun('Bans') --> ['Bans'].
proper_noun('Cergy') --> ['Cergy'].
proper_noun('Bellefontaine') --> ['Bellefontaine'].
proper_noun('Beaumont_sur_Oise') --> ['Beaumont_sur_Oise'].
proper_noun('Blanc_Mesnil') --> ['Blanc_Mesnil'].
proper_noun('Bossoutrot') --> ['Bossoutrot'].
proper_noun('Camille_Claudel') --> ['Camille_Claudel'].
proper_noun('M._C_Delon') --> ['C_Delon'].
proper_noun('Condos') --> ['Condos'].
proper_noun('Draguignan') --> ['Draguignan'].
proper_noun('Ecouen') --> ['Ecouen'].
proper_noun('E_Quinet') --> ['E_Quinet'].
proper_noun('Ermitage') --> ['Ermitage'].
proper_noun('Est') --> ['Est'].
proper_noun('Foch') --> ['Foch'].
proper_noun('Gal_De_Gaulle') --> ['Gal_De_Gaulle'].
proper_noun('Mours') --> ['Mours'].
proper_noun('Ford') --> ['Ford'].
proper_noun('FG_Lorca') --> ['FG_Lorca'].
proper_noun('Franconville') --> ['Franconville'].
proper_noun('Genevilliers') --> ['Genevilliers'].
proper_noun('Gennevilliers') --> ['Gennevilliers'].
proper_noun('Herblay') --> ['Herblay'].
proper_noun('Italiens') --> ['Italiens'].
proper_noun('Jouy_le_Moutier') --> ['Jouy_le_Moutier']. 
proper_noun('Montmorency') --> ['Montmorency'].
proper_noun('Nanterre') --> ['Nanterre'].
proper_noun('Maryse') --> ['Maryse'].
proper_noun('Pantin') --> ['Pantin'].
proper_noun('Pasteur') --> ['Pasteur'].
proper_noun('Poissy') --> ['Poissy'].
proper_noun('Prsident_Wilson') --> ['Prsident_Wilson'].
proper_noun('P_Doumer') --> ['P_Doumer'].
proper_noun('Ren_Coty') --> ['Ren_Coty'].
proper_noun('Renault') --> ['Renault'].
proper_noun(renault) --> [renault].
proper_noun('Saint_Ouen') --> ['Saint_Ouen'].
proper_noun('St_Brice') --> ['St_Brice'].
proper_noun('St_Martin_du_Tertre') --> ['St_Martin_du_Tertre'].
proper_noun('Sannois') --> ['Sannois'].
proper_noun('Saulnier') --> ['Saulnier'].
proper_noun('Senlis') --> ['Senlis'].
proper_noun('Sud') --> ['Sud'].
proper_noun('Taupinires') --> ['Taupinires'].
proper_noun('Taverny') --> ['Taverny'].
proper_noun('Thorez') --> ['Thorez'].
proper_noun('Peugeot') --> ['Peugeot'].
proper_noun('4L') --> ['4L'].
proper_noun('9TSE') --> ['9TSE'].
proper_noun('R11') --> ['R11'].
proper_noun('R21') --> ['R21'].
proper_noun('Villiers_Adam') --> ['Villiers_Adam']. 
proper_noun('Roger_Levanneur') --> ['Roger_Levanneur'].
proper_noun('Pierre_Curie') --> ['Pierre_Curie'].
proper_noun('St_Prix') --> ['St_Prix'].
proper_noun('gd_Leclerc') --> ['gd_Leclerc'].
proper_noun('Dct_Leray') --> ['Dct_Leray'].
proper_noun('Maurice_Berteaux') --> ['Maurice_Berteaux'].
proper_noun('Renault_21') --> ['Renault_21'].
proper_noun('Peugeot_205') --> ['Peugeot_205'].
proper_noun('205') --> ['205'].
proper_noun('Couturier') --> ['Couturier'].
proper_noun('Constantinide') --> ['Constantinide'].
proper_noun('Morinval') --> ['Morinval'].
proper_noun('Rene_Briand') --> ['Rene_Briand'].
proper_noun('Sbastopol') --> ['Sbastopol'].
proper_noun('N17') --> ['N17'].

proper_noun(Name) -->
	['Mr'], [X], 
	{name('M._', L1), name(X, L2), append(L1, L2, L3), name(Name, L3)}.
proper_noun(Name) -->
	['Mme'], [X], 
	{name('Mme_', L1), name(X, L2), append(L1, L2, L3), name(Name, L3)}.
proper_noun(Name) -->
	['Melle'], [X], 
	{name('Mlle_', L1), name(X, L2), append(L1, L2, L3), name(Name, L3)}.


infinitive(aller) --> [aller].
infinitive(apercevoir) --> [apercevoir].
infinitive(appeler) --> [appeler].
infinitive(approcher) --> [approcher].
infinitive(arrter) --> [arrter].
infinitive(assurer) --> [assurer].
infinitive(attendre) --> [attendre].
infinitive(braquer) --> [braquer].
infinitive(changer) --> [changer].
infinitive(continuer) --> [continuer].
infinitive(contrler) --> [contrler].
infinitive(couper) --> [couper].
infinitive(cder) --> [cder].
infinitive(diriger) --> [diriger].
infinitive(doubler) --> [doubler].
infinitive(dgager) --> [dgager].
infinitive(dgonfler) --> [dgonfler].
infinitive(dlibrer) --> [dlibrer].
infinitive(dpasser) --> [dpasser].
infinitive(dporter) --> [dporter].
infinitive(draper) --> [draper].
infinitive(emboutir) --> [emboutir].
infinitive(emprunter) --> [emprunter].
infinitive(engager) --> [engager].
infinitive(faire) --> [faire].
infinitive(faire_le_tour) --> [faire_le_tour].
infinitive(finir) --> [finir].
infinitive(freiner) --> [freiner].
infinitive(heurter) --> [heurter].
infinitive(indiquer) --> [indiquer].
infinitive(inspecter) --> [inspecter].
infinitive(juger) --> [juger].
infinitive(laisser) --> [laisser].
infinitive(marquer) --> [marquer].
infinitive(passer) --> [passer].
infinitive(percuter) --> [percuter].
infinitive(perdre) --> [perdre].
infinitive(prendre) --> [prendre].
infinitive(projeter) --> [projeter].
infinitive(prvoir) --> [prvoir].
infinitive(reculer) --> [reculer].
infinitive(redmarrer) --> [redmarrer].
infinitive(regarder) --> [regarder].
infinitive(rejoindre) --> [rejoindre].
infinitive(relcher) --> [relcher].
infinitive(rendre) --> [rendre].
infinitive(rentrer) --> [rentrer].
infinitive(repartir) --> [repartir].
infinitive(signaler) --> [signaler].
infinitive(sortir) --> [sortir].
infinitive(stopper) --> [stopper].
infinitive(tenir) --> [tenir].
infinitive(tordre) --> [tordre].
infinitive(toucher) --> [toucher].
infinitive(tourner) --> [tourner].
infinitive(tracter) --> [tracter].
infinitive(traverser) --> [traverser].
infinitive(voir) --> [voir].
infinitive(craser) --> [craser].
infinitive(tablir) --> [tablir].
infinitive(viter) --> [viter].
infinitive(X) --> aux_infinitive(X).

aux_infinitive(avoir) --> [avoir].
aux_infinitive(tre) --> [tre].


past_participle('Entraner') --> ['Entran'].
past_participle('Voir') --> ['Vu'].
past_participle('Arrter') --> ['Arrt'].
past_participle('Arrter') --> ['Arrte'].
past_participle('Heurter') --> ['Heurt'].
past_participle('Prsenter') --> ['Prsente'].

past_participle(aborder) --> [aborde].
past_participle(abmer) --> [abm].
past_participle(accentuer) --> [accentu].
past_participle(accidenter) --> [accident].
past_participle(accrocher) --> [accroch].
past_participle(aller) --> [all].
past_participle(amorcer) --> [amorc].
past_participle(amnager) --> [amnag].
past_participle(apprcier) --> [apprci].
past_participle(appuyer) --> [appuy].
past_participle(arriver) --> [arriv].
past_participle(arriver) --> [arrive].
past_participle(arrter) --> [arrt].
past_participle(arrter) --> [arrte].
past_participle(arrter) --> [arrtes].
past_participle(arrter) --> [arrts].
past_participle(barrer) --> [barre].
past_participle(braquer) --> [braqu].
past_participle(briser) --> [bris].
past_participle(buter) --> [but].
past_participle(buter) --> [butes].
past_participle(caler) --> [cal].
past_participle(causer) --> [caus].
past_participle(changer) --> [chang].
past_participle(citer) --> [cit].
past_participle(clouter) --> [clout].
past_participle(cogner) --> ['"',cogn,'"'].
past_participle(cogner) --> [cogn].

past_participle(commencer) --> [commenc].
past_participle(commettre) --> [commis].
past_participle(constater) --> [constat].
past_participle(contenter) --> [contente].
past_participle(continuer) --> [continu].
past_participle(couper) --> [coup].
past_participle(couper) --> [coupe].
past_participle(croire) --> [cru].
past_participle(cder) --> [cd].
past_participle(demander) --> [demand].
past_participle(dire) --> [dit].
past_participle(doubler) --> [doubl].
past_participle(dclarer) --> [dclar].
past_participle(dmarrer) --> [dmarr].
past_participle(dpasser) --> [dpass].
past_participle(dporter) --> [dport].
past_participle(draper) --> [drap].
past_participle(devoir) --> [d].
past_participle(effectuer) --> [effectu].
past_participle(empiter) --> [empit].
past_participle(empcher) --> [empch].
past_participle(enclencher) --> [enclench].
past_participle(endommager) --> [endommag].
past_participle(endommager) --> [endommage].
past_participle(enfoncer) --> [enfonc].
past_participle(enfoncer) --> [enfonce].
past_participle(engager) --> [engag].
past_participle(engager) --> [engage].
past_participle(entendre) --> [entendu].
past_participle(entraner) --> [entran].
past_participle(essayer) --> [essay].
past_participle(faire) --> [fait].
past_participle(finir) --> [fini].
past_participle(finir) --> [finit]. % Wrong! but occurs in the corpus
past_participle(forcer) --> [forc].
past_participle(franchir) --> [franchi].
past_participle(freiner) --> [frein].
past_participle(frotter) --> [frott].
past_participle(garer) --> [gar].
past_participle(glisser) --> [gliss].
past_participle(heurter) --> [heurt].
past_participle(heurter) --> [heurte].
past_participle(heurter) --> [heurts].
past_participle(immatriculer) --> [immatricule].
past_participle(immobiliser) --> [immobilis].
past_participle(indiquer) --> [indiqu].
past_participle(inexpliquer) --> [inexplique].
past_participle(interdire) --> [interdit].
past_participle(lever) --> [lev].
past_participle(limiter) --> [limite].
past_participle(lcher) --> [lch].
past_participle(masquer) --> [masque].
past_participle(matrialiser) --> [matrialises].
past_participle(mettre) --> [mis].
past_participle(mouiller) --> [mouille].
past_participle(nommer) --> [nomm].
past_participle(ordonner) --> [ordonn].
past_participle(oublier) --> [oubli].
past_participle(ouvrir) --> [ouvert].
past_participle(ouvrir) --> [ouverte].
past_participle(passer) --> [pass].
past_participle(percuter) --> [percut].
past_participle(percuter) --> [percutes].
past_participle(percuter) --> [percuts].
past_participle(perdre) --> [perdu].
past_participle(perturber) --> [perturbe].
past_participle(pointiller) --> [pointille].
past_participle(pousser) --> [pouss].
past_participle(prendre) --> [pris].
past_participle(produire) --> [produit].
past_participle(projeter) --> [projet].
past_participle(provoquer) --> [provoqu].
past_participle(pouvoir) --> [pu].
past_participle(quitter) --> [quitt].
past_participle(rabattre) --> [rabattu].
past_participle(rajouter) --> [rajout].
past_participle(ranger) --> [rang].
past_participle(rapprocher) --> [rapproches].
past_participle(rayer) --> [ray].
past_participle(reconnaitre) --> [reconnu].
past_participle(reculer) --> [recul].
past_participle(redmarrer) --> [redmarr].
past_participle(refuser) --> [refuse].
past_participle(rejoindre) --> [rejoint].
past_participle(remplir) --> [rempli].
past_participle(rendre) --> [rendu].
past_participle(rendre) --> [rendus].
past_participle(repartir) --> [reparti].
past_participle(reprsenter) --> [reprsente].
past_participle(respecter) --> [respect].
past_participle(ressentir) --> [ressenti].
past_participle(retrouver) --> [retrouv].
past_participle(retrouver) --> [retrouve].
past_participle(recevoir) --> [reu].
past_participle(racclrer) --> [racclr].
past_participle(rpondre) --> [rpondu].
past_participle(rserver) --> [rserve].
past_participle(russir) --> [russi].
past_participle(serrer) --> [serr].
past_participle(serrer) --> [serre].
past_participle(signer) --> [sign].
past_participle(situer) --> [situe].
past_participle(stationner) --> [stationn].
past_participle(stopper) --> [stopp].
past_participle(subir) --> [subi].
past_participle(suffir) --> [suffi].
past_participle(surprendre) --> [surpris].
past_participle(surprendre) --> [surprise].
past_participle(sparer) --> [spar].
past_participle(taper) --> [tap].
past_participle(tomber) --> [tomb].
past_participle(toucher) --> [touch].
past_participle(toucher) --> [touche].
past_participle(tourner) --> [tourn].
past_participle(traverser) --> [travers].
past_participle(venir) --> [venu].
past_participle(venir) --> [venue].
past_participle(vouloir) --> [voulu].
past_participle(voir) --> [vu].
past_participle(changer) --> [chang].
past_participle(jecter) --> [ject].
past_participle(tablir) --> [tabli].
past_participle(ternuer) --> [ternu].
past_participle(viter) --> [vit].
past_participle(viter) --> [vite].

gerund('vouloir') --> ['Voulant'].
gerund('serrer') --> ['Serrant'].
gerund('surgir') --> ['Surgissant'].
gerund('venir') --> ['Venant'].
gerund('circuler') --> ['Circulant'].
gerund('sortir') --> ['Sortant'].
gerund('rouler') --> ['Roulant'].
gerund('revenir') --> ['Revenant'].
gerund('penser') --> ['Pensant'].
gerund('arriver') --> ['Arrivant'].
gerund('conduire') --> ['Conduisant'].
gerund('voir') --> ['Voyant'].


gerund(aborder) --> [abordant].
gerund(abmer) --> [abmant].
gerund(aller) --> [allant].
gerund(apprter) --> [apprtant].
gerund(arriver) --> [arrivant].
gerund(attendre) --> [attendant].
gerund(aveugler) --> [aveuglant].
gerund(circuler) --> [circulant].
gerund(clignoter) --> [clignotant].
gerund(doubler) --> [doublant].
gerund(dpasser) --> [dpassant].
gerund(dporter) --> [dportant].
gerund(dsirer) --> [dsirant].
gerund(emboter) --> [embotant].
gerund(enfoncer) --> [enfonant].
gerund(entraner) --> [entranant].
gerund(expliquer) --> [expliquant].
gerund(faire) --> [faisant].
gerund(franchir) --> [franchissant].
gerund(heurter) --> [heurtant].
gerund(laisser) --> [laissant].
gerund(obliger) --> [obligeant].
gerund(passer) --> [passant].
gerund(penser) --> [pensant].
gerund(prendre) --> [prenant].
gerund(projeter) --> [projetant].
gerund(provenir) --> [provenant].
gerund(provoquer) --> [provoquant].
gerund(prcder) --> [prcdant].
gerund(rapprocher) --> [rapprochant].
gerund(reculer) --> [reculant].
gerund(regarder) --> [regardant].
gerund(rendre) --> [rendant].
gerund(respecter) --> [respectant].
gerund(rouler) --> [roulant].
gerund(sortir) --> [sortant].
gerund(toucher) --> [touchant].
gerund(tourner) --> [tournant].
gerund(trouver) --> [trouvant].
gerund(venir) --> [venant].
gerund(virer) --> [virant].
gerund(vouloir) --> [voulant].


aux_conj_gerund_be(tre) --> ['Etant'].
aux_conj_gerund_be(tre) --> [tant].     %%%%%%%

aux_conj_gerund_have('Ayant') --> ['Ayant'].
aux_conj_gerund_have(ayant) --> [ayant].

aux_conj_gerund(X) --> aux_conj_gerund_be(X).
aux_conj_gerund(X) --> aux_conj_gerund_have(X).

multiword(_ce_qu) --> [, ce, qu], [''''].
multiword('Alors_que') --> ['Alors', que].
multiword(alors_que) --> [alors, que].
multiword(avant_que) --> [avant, que].
multiword('Av') --> ['Av', '.'].
multiword('Bien_entendu') --> ['Bien', entendu].
multiword(ave) --> [ave, '.'].
multiword(autoroute_A1) --> [autoroute, 'A1'].
multiword(au_loin) --> [au, loin].
multiword(au_moment_de) --> [au, moment, de].
multiword(au_moment_du) --> [au, moment, du].
multiword(_droite) --> [, droite].
multiword(_gauche) --> [, gauche].
multiword('Beaumont_sur_Oise') --> ['Beaumont', sur, 'Oise'].
multiword('Blanc_Mesnil') --> ['Blanc', 'Mesnil'].
multiword('Camille_Claudel') --> ['Camille', 'Claudel'].
multiword(celle_ci) --> [celle, '-', ci].
multiword(celui_ci) --> [celui, '-', ci].
multiword(ce_qui) --> [ce, qui].
multiword(ce_qu) --> [ce, qu], [''''].
multiword('Celui_ci') --> ['Celui', '-', ci].
multiword('C_Delon') --> ['C', '.', 'Delon'].
multiword('D_aprs') --> ['D'], [''''], [aprs].
multiword(en_face) --> [en, face].
multiword('E_Quinet') --> ['E', '.', 'Quinet'].
multiword('FG_Lorca') --> ['F', '.', 'G', '.', 'Lorca'].
multiword(du_tout) --> [du, tout].
multiword(face_au) --> [face, au].
multiword(faire_le_tour) --> [faire, le, tour].
multiword(hors_de) --> [hors, de].
multiword('Jouy_le_Moutier') --> ['Jouy', le, 'Moutier'].
multiword(juste_aprs) --> [juste, aprs].
multiword(juste_avant) --> [juste, avant].
multiword(la_mienne) --> [la, mienne].
multiword(le_sien) --> [le, sien].
multiword(l_une_des) --> [l], [''''], [une], [des].
multiword('Lors_d') --> ['Lors', d], [''''].
multiword(lors_du) --> [lors], [du].
multiword('P_Doumer') --> ['P', '.', 'Doumer'].
multiword(par_consquent) --> [par, consquent].
multiword(pare_chocs) --> [pare, '-', choc].
multiword(pare_chocs) --> [pare, '-', chocs].
multiword(pare_chocs) --> [pare, choc].
multiword(beaucoup_de) --> [beaucoup, de].
%multiword(pas_de) --> [pas], [de].
multiword('Pas_de') --> ['Pas'], [de].
multiword(plus_de) --> [plus, de].
multiword(prs_de) --> [prs, de].
multiword(rond_point) --> [rond, '-', point].
multiword(rond_point) --> [rond, point].
multiword('Saint_Ouen') --> ['Saint', '-', 'Ouen'].
multiword('St_Brice') --> ['St', 'Brice'].
multiword('St_Martin_du_Tertre') --> ['St', 'Martin', du, 'Tertre'].
multiword(si_bien_que) --> [si, bien, que].
multiword(semi_remorque) --> [semi, '-', remorque].
multiword(station_service) --> [station, service].
multiword(sans_doute) --> [sans, doute].
multiword(sous_sol) --> [sous, '-', sol].
multiword(tout_droit) --> [tout, droit].
multiword(toute_la) --> [toute, la].
multiword(tout_le) --> [tout, le].
multiword(tout__fait) --> [tout, , fait].
multiword(vhicules_A_et_B) --> [vhicules, 'A', et, 'B']. 
multiword(vhicule_a) --> [veh, 'A'], {!}.
multiword(vhicule_a) --> [premire, voiture], {!}. % ajout
multiword(vhicule_a) --> [vhicule, 'A'], {!}.
multiword(vhicule_a) --> [voiture, 'A'], {!}.
multiword(vhicule_b) --> ['Vhicule', 'B'], {!}.
multiword(vhicule_b) --> [vhicule, 'B'], {!}.
multiword(vhicule_b) --> [deuxime, voiture], {!}. % ajout
multiword(vhicule_b) --> [voiture, 'B'], {!}.
multiword(vhicule_b) --> [voiture, '"', 'B', '"'], {!}.
multiword(vhicule_c) --> ['3ime',vhicule], {!}.
multiword(vhicule_c) --> [vhicule, 'C'], {!}.
multiword('A_et_B') --> ['A', et, 'B'].
multiword(camion_de_dpannage) -->[camion, de, dpannage].% ajout
multiword(_peine) --> [, peine].

multiword(elle) --> [elle,-,mme].%ajout

multiword('Ren_Coty') --> ['Ren', 'Coty'].
multiword('Gal_De_Gaulle') --> ['Gal', 'De', 'Gaulle'].
multiword('Prsident_Wilson') --> ['Prsident', 'Wilson'].
multiword('Villiers_Adam') --> ['Villiers', '-','Adam'].

multiword('Roger_Levanneur') --> ['Roger', 'Levanneur'].
multiword('Pierre_Curie') --> ['Pierre', 'Curie'].
multiword('St_Prix') --> ['St', 'Prix'].
multiword('gd_Leclerc') --> ['gd', 'Leclerc'].
multiword('Dct_Leray') --> ['Dct', 'Leray'].
multiword('Maurice_Berteaux') --> ['Maurice', 'Berteaux'].
% multiword('Renault_21') --> ['Renault',  21].  
%multiword('Ford') --> ['Ford',  sierra]. % ajout
multiword('R21') --> ['Renault',  21]. % ajout
multiword('205') --> ['Peugeot', 205].
multiword('Rene_Briand') --> ['Rene', 'Briand'].



multiword(X) --> date_value(X).
multiword(X) --> distance(X).
multiword(X) --> time_value(X).
multiword(X) --> number_plate(X).

%multiword(speed_value) --> speed(X).

number_plate(no_immatriculation) -->
	[Number], [A], [Dept], 
	{number(Number), name(A, L), length(L, N), (N =:= 2; N =:= 3), number(Dept),
	Dept < 100}.

date_value(date_value) -->
	[Day, '/', Month, '/', Year],
	{number(Day), number(Month), number(Year)}.
date_value(date_value) -->
	[Day, '-', Month, '-', Year],
	{number(Day), number(Month), number(Year)}.
date_value(date_value) -->
	[Day, '-', Month, '/', Year],
	{number(Day), number(Month), number(Year)}.

time_value(time_value) -->
	[X],
	{name(X, L), reverse(L, [h | LR]), number(LR)}.
time_value(time_value) -->
	[Hour, h, Minutes],
	{number(Hour), number(Minutes)}.

speed(LS) --> adv(RB1), speed_val(S), adv(RB2), {append([RB1 | S], RB2, LS)}.
speed([RB | S]) --> adv(RB), speed_val(S).
speed(LS) --> speed_val(S), adv(RB), {append(S, RB, LS)}.
speed(S) --> speed_val(S).

speed_val([Number, kmh]) -->
	[Number], [km], ['/'], [h], 
	{number(Number)}.
speed_val([Number, kmh]) -->
	[Number], ['Km'], ['/'], [h], 
	{number(Number)}.

distance(distance_value) -->
	[Number], [mtres], 
	{number(Number)}.

/*multiword() --> [].

*/
 
aux_conj_have('Ai') --> ['Ai'].
aux_conj_have(a) --> [a].
aux_conj_have(ai) --> [ai].
aux_conj_have(ait) --> [ait].
aux_conj_have(aurait) --> [aurait].
aux_conj_have(avaient) --> [avaient].
aux_conj_have(avais) --> [avais].
aux_conj_have(avait) --> [avait].
aux_conj_have(avons) --> [avons].
aux_conj_have(ont) --> [ont].
aux_conj_have(eu) --> [eu].
aux_conj_have(eut) --> [eut].


aux_conj_be(est) --> [est].
aux_conj_be(taient) --> [taient].
aux_conj_be(tais) --> [tais].
aux_conj_be(tait) --> [tait].
aux_conj_be(tions) --> [tions].
aux_conj_be(t) --> [t].
aux_conj_be(fut) --> [fut]. % changement
aux_conj_be(soit) --> [soit].
aux_conj_be(sommes) --> [sommes].
aux_conj_be(sont) --> [sont].
aux_conj_be(suis) --> [suis].


aux_conj(X) --> aux_conj_have(X).
aux_conj(X) --> aux_conj_be(X).
aux_conj(X) --> aux_conj_gerund(X).

tensed_verb(aborder) --> [abordais].
tensed_verb(aller) --> [allais].
tensed_verb(aller) --> [allait].
tensed_verb(amorcer) --> [amorcions].
tensed_verb(apprter) --> [apprtais].
tensed_verb(apprter) --> [apprtait].
tensed_verb(arriver) --> [arrivais].
tensed_verb(arriver) --> [arrivait].
tensed_verb(atteindre) --> [atteint].
tensed_verb(attendre) --> [attendais].
tensed_verb(avrer) --> [avre].
tensed_verb(basculer) --> [bascula].
tensed_verb(casser) --> [cassait].
tensed_verb(circuler) --> [circulais].
tensed_verb(circuler) --> [circulait].
tensed_verb(clignoter) --> [clignotais].
tensed_verb(commener) --> [commenais].
tensed_verb(continuer) --> [continue].
tensed_verb(cder) --> [cdez].
tensed_verb(descendre) --> [descendais].
tensed_verb(devoir) --> [devais].
tensed_verb(dmarrer) --> [dmarrais].
tensed_verb(dmarrer) --> [dmarrait].
tensed_verb(dpasser) --> [dpassait].
tensed_verb(draper) --> [drape].
tensed_verb(dsirer) --> [dsirais].
tensed_verb(dsirer) --> [dsire].
tensed_verb(effectuer) --> [effectue].
tensed_verb(empiter) --> [empitait].
tensed_verb(engager) --> [engageais].
tensed_verb(estimer) --> [estimais].
tensed_verb(expliquer) --> [explique].
tensed_verb(finir) --> [finit].
tensed_verb(faire) --> [fis].
tensed_verb(faire) --> [fit].
tensed_verb(fonctionner) --> [fonctionnaient].
tensed_verb(freiner) --> [freinais].
tensed_verb(freiner) --> [freinerait].
tensed_verb(glisser) --> [glissa].
tensed_verb(heurter) --> [heurtais].
tensed_verb(heurter) --> [heurte].
tensed_verb(ignorer) --> [ignore].
tensed_verb(indiquer) --> [indiquaient].
tensed_verb(inverser) --> [inversait].
tensed_verb(laisser) --> [laissait].
tensed_verb(laisser) --> [laisserait].
tensed_verb(maintenir) --> [maintiens].
tensed_verb(obliger) --> [obligeait].
tensed_verb(passer) --> [passait].
tensed_verb(percuter) --> [percuta].
tensed_verb(percuter) --> [percutais].
tensed_verb(percuter) --> [percute].
tensed_verb(permettre) --> [permettaient].
tensed_verb(pleuvoir) --> [pleuvait].
tensed_verb(pouvoir) --> [pourrait].
tensed_verb(pouvoir) --> [pouvais].
tensed_verb(pouvoir) --> [pouvait].
tensed_verb(prendre) --> [prend].
tensed_verb(prcder) --> [prcdait].
tensed_verb(pouvoir) --> [pus].
tensed_verb(rabattre) --> [rabattais].
tensed_verb(ralentir) --> [ralentis].
tensed_verb(reculer) --> [reculais].
tensed_verb(reculer) --> [reculait].
tensed_verb(redmarrer) --> [redmarrais].
tensed_verb(redmarrer) --> [redmarre].
tensed_verb(refuser) --> [refuse].
tensed_verb(regarder) --> [regardais].
tensed_verb(regarder) --> [regardait].
tensed_verb(rendre) --> [rendais].
tensed_verb(rentrer) --> [rentrais].
tensed_verb(rentrer) --> [rentrions].
tensed_verb(rouler) --> [roulaient].
tensed_verb(rouler) --> [roulais].
tensed_verb(rouler) --> [roulait].
tensed_verb(rouler) --> [roulions].
tensed_verb(rsider) --> [rside].
tensed_verb(signaler) --> [signale].
tensed_verb(slalomer) --> [slalomait].
tensed_verb(sortir) --> [sortais].
tensed_verb(sortir) --> [sortait].
tensed_verb(souhaiter) --> [souhaitait].
tensed_verb(stationner) --> [stationnaient].
tensed_verb(stationner) --> [stationnais].
tensed_verb(stationner) --> [stationnait].
tensed_verb(suivre) --> [suivait].
tensed_verb(surgir) --> [surgit].
tensed_verb(tenir) --> [tenais].
tensed_verb(tenir) --> [tiens].
tensed_verb(tourner) --> [tourna].
tensed_verb(tourner) --> [tournait].
tensed_verb(tourner) --> [tournions].
tensed_verb(traverser) --> [traversait].
tensed_verb(trouver) --> [trouvais].
tensed_verb(trouver) --> [trouvait].
tensed_verb(trouver) --> [trouve].
tensed_verb(venir) --> [venaient].
tensed_verb(venir) --> [venais].
tensed_verb(venir) --> [venait].
tensed_verb(virer) --> [virais].
tensed_verb(vouloir) --> [voulait].
tensed_verb(voir) --> [voyais].

tensed_verb(tre) --> [tais]. % rajout ajout

tensed_verb(X) --> aux_conj(X).



/*
multiword(ntexte) -->
	['Texte'], [X], {!}.
multiword(Name) -->
	['M.'], [X],
	{name('M_', L1), name(X, L2),
	append(L1, L2, LName), name(Name, LName)}.
multiword(Value) -->
	[X], ['DM'],
	{name('DM_', L1),
	number(X), name(X, L2),
	append(L1, L2, LValue), name(Value, LValue)}.
*/

