% Tokenize.pl contains predicates to read the corpus, to parse the XML code,
% to tokenize the words, and to detect sentences.
% Created and modified by Pierre Nugues


% Read the reports
read_corpus(CorpusName, CorpusTokens) :-
	read_file(CorpusName, CorpusChar),
	tokens(CorpusTokens, CorpusChar, []).

% Parses the XML-like syntactic description of the corpus
parse_xml_corpus(Corpus) -->
	['<', 'CORPUS', '>'],
	reports(Corpus),
	['<', '/', 'CORPUS', '>'].

reports([Report]) -->
	report(Report).
reports(Corpus) -->
	report(Report),
	reports(RestReports),
	{append([Report], RestReports, Corpus)}.

report([ReportNumber | Body]) --> 
	['<', 'REPORT', 'ID', '=', '"'],
	report_number(ReportNumber),
	['"', '>'],
	report_body(Body),
	['<', '/', 'REPORT', '>'].

report_number([ReportID]) -->
	[ReportID].
report_number([FirstID | RestID]) -->
	[FirstID],
	{FirstID \== '"'},
	report_number(RestID).

report_body([Token | RestBody]) -->
	[Token],
	{Token \== '<'},
	report_body(RestBody).
report_body([]) --> [].

tokens(Tokens) --> blank, {!}, tokens(Tokens).
tokens([FirstT | Tokens]) --> token(FirstT), {!}, tokens(Tokens).
tokens([]) --> [].

% A blank is a white space or a control character
blank --> [B], {B =< 32, !}.

% A token is a sequence of alphanumeric characters 
% or another symbol

token(Word) --> alphanumerics(List), {name(Word, List), !}.
token(Symbol) --> other(CSymbol), {name(Symbol, [CSymbol]), !}.

% A sequence of alphanumerics is an alphanumeric character 
% followed by the rest of alphanumerics or a 
% single alphanumeric character.

alphanumerics([L | LS]) --> alphanumeric(L), alphanumerics(LS).
alphanumerics([L]) --> alphanumeric(L).


% Here comes the definition of alphanumeric characters: digits,
% upper-case letters without accent, lower-case letters without 
% accent, and accented characters. Here we only consider
% letters common in French and German

% digits
alphanumeric(D) --> [D], { 48 =< D, D =< 57, !}.

% upper-case letters without accent
alphanumeric(L) --> [L], {65 =< L, L =< 90, !}.

% lower-case letters without accent
alphanumeric(L) --> [L], {97 =< L, L =< 122, !}.

% accented characters
alphanumeric(L) --> [L], {name(A, [L]), accented(A), !}.

accented(L) :-
	member(L, [, , , , , , , , , , , , , '', , , , , , 
	'', '', '', '', '', '', '', '', '', '', '', '', '', '',
	'', '', '', '', '']).
% All other symbols come here
other(39) --> [L], {(L =:= 180; L =:= 146), !}. % Specific processing of 
								% slanted apostrophs replaced by 
								% straight ones
other(Symbol) --> [Symbol], {!}.

sentences([S | RS]) -->
	words_of_a_sentence(S),
	sentences(RS).
sentences([S]) -->	% The last sentence (punctuated)
	words_of_a_sentence(S).
sentences([S]) -->	% Last sentence (no final punctuation)
	words_without_punctuation(S).

words_of_a_sentence([P]) -->
	end_punctuation(P).
words_of_a_sentence([W | RS]) --> 
	word(W),
	words_of_a_sentence(RS).

words_without_punctuation([W | RS]) -->
	word(W),
	words_without_punctuation(RS).
words_without_punctuation([W]) --> [W].

word(W) --> [W].

end_punctuation(P) --> [P], {end_punctuation(P), !}. 

/*end_punctuation(P) :-
	member(P, ['.', ';', ':', '?', '!']).
*/
end_punctuation(P) :-
	member(P, ['.', ';', '?', '!']).
